@@ -6,9 +6,9 @@ class Parser:
 
     scraper = None
 
-    def __init__(self, config: Config, headless: bool=True) -> None:
+    def __init__(self, config: Config, headless: bool=True, window: dict={}) -> None:
         self.config = config
-        self.scraper = self.get_scraper(headless=headless)
+        self.scraper = self.get_scraper(headless=headless, window=window)
 
     # region methods
     def click(self, path: str, element: any=None, timeout: int=0) -> any:
@@ -58,7 +58,7 @@ class Parser:
 
     #endregion methods
 
-    def get_scraper(self, headless: bool=True) -> Scraper:
+    def get_scraper(self, headless: bool=True, window: dict={}) -> Scraper:
         scraper_type = self.config.get('PROJECT', 'scraper')
         if scraper_type is not None:
             module_name = self.config.get('PROJECT', 'scraper')
@@ -67,4 +67,4 @@ class Parser:
             module_name = 'selenium'
             class_name = 'Selenium'
 
-        return Utils.instantiate(module_name=f'scrapeanything.scraper.scrapers.{module_name}', class_name=class_name, args={ 'headless': headless })
\ No newline at end of file
+        return Utils.instantiate(module_name=f'scrapeanything.scraper.scrapers.{module_name}', class_name=class_name, args={ 'headless': headless, 'window': window })
\ No newline at end of file
