@@ -108,7 +108,7 @@ class Scraper:
 
         return el
 
-    def exists(self, path: str, element: any, timeout: int=0):
+    def exists(self, path: str, element: any=None, timeout: int=0):
         return self.on_exists(path=path, element=element, timeout=timeout)
 
     def substring(self, el: any, substring: str):
