@@ -102,13 +102,16 @@ class Selenium(Scraper):
                 element = element[0]
 
             try:
-                actions = ActionChains(self.driver)
-                actions.click(element).perform()
-            except:
+                self.driver.execute_script("arguments[0].click();", element)
+            except Exception as e:
                 try:
-                    self.driver.execute_script("arguments[0].click();", element)
-                except Exception as e:
                     element.click()
+                except:
+                    try:
+                        actions = ActionChains(self.driver)
+                        actions.click(element).perform()
+                    except:
+                        return None
 
             return element
         else:
